@@ -5,8 +5,6 @@ use base qw(IUP::Internal::Canvas);
 use IUP::Internal::LibraryIup;
 use Carp;
 
-#XXX-FIXME IUP::Canvas::EMF will be replaced by IUP::Canvas::FileVector
-
 sub new {
   my ($self, %args) = @_;
   my $filename = $args{filename};
@@ -28,7 +26,7 @@ sub new {
     my $init = $filename;
     $init .= ' '.int($width).'x'.int($height) if defined $width && defined $height;
     #warn "DEBUG init='$init'\n";
-    $ch = $self->new_from_cnvhandle(IUP::Internal::Canvas::_cdCreateCanvas_BASIC("EMF", $init));
+    $ch = $self->new_from_cnvhandle(IUP::Internal::Canvas::_cdCreateCanvas_FILE("EMF", $init));
   }
   return $ch;
 }
